@@ -185,16 +185,15 @@ def get_mqtt_status():
 class Dxr_Subscriber:
     def __init__(self, topic, callback):
         global callback_dit, topic_list_str_pub, topic_list_str_sub, mqttc, sn
-        if sn is not None and sn not in topic:
-            topic = f'/{sn}/client{topic}'
         if mqttc is None:
             mqttc = Mqtt()
         if isinstance(topic, str):
-            mqttc.subscribe(topic)
             self.topic = topic
         else:
-            mqttc.subscribe(topic.topic)
             self.topic = topic.topic
+        if sn is not None and sn not in self.topic:
+            self.topic = f'/{sn}/client{self.topic}'
+        mqttc.subscribe(self.topic)
         self.callback = callback
         if self.topic not in callback_dit:
             cond = threading.Event()
